@@ -29,14 +29,14 @@
 #include <stdio.h>
 #include <signal.h>
 
-#if !defined (_WIN32)
+#if !defined(_WIN32) && !defined(_WIN64)
 # include <pwd.h>
 #endif
 
 #include <sys/types.h>
 #include <ctype.h>
 
-#if defined(_WIN32)
+#if defined(_WIN32) || defined(_WIN64)
 # include <io.h>
 # if !defined(NOTCYGWIN)
 /*
@@ -49,7 +49,7 @@
 # endif
 # define strdup _strdup
 # define isatty _isatty
-#endif /* Windoz */
+#endif /* Windows */
 
 #define CALC_C
 #include "calc.h"
@@ -548,7 +548,6 @@ main(int argc, char **argv)
 		setbuf(stdout, NULL);
 	}
 
-
 	/*
 	 * initialize
 	 */
@@ -705,18 +704,18 @@ main(int argc, char **argv)
 			if (!p_flag && i_flag && !stdin_tty) {
 				closeinput();
 				if(!freopen("/dev/tty", "r", stdin)) {
-#if defined (_WIN32)
+#if defined(_WIN32) || defined(_WIN64)
 					fprintf(stderr,
 						"/dev/tty does not exist on "
 						"this operating system.  "
 						"Change operating systems\n"
 						"or don't use this calc mode "
 						"in the future, sorry!\n");
-#else /* Windoz free systems */
+#else /* Windows free systems */
 					fprintf(stderr,
 						"Unable to associate stdin"
 						" with /dev/tty");
-#endif /* Windoz free systems */
+#endif /* Windows free systems */
 					set_run_state(RUN_EXIT_WITH_ERROR);
 					break;
 				}
@@ -735,18 +734,18 @@ main(int argc, char **argv)
 					!p_flag && (!havecommands||i_flag)) {
 				closeinput();
 				if(!freopen("/dev/tty", "r", stdin)) {
-#if defined (_WIN32)
+#if defined(_WIN32) || defined(_WIN64)
 					fprintf(stderr,
 						"/dev/tty does not exist on "
 						"this operating system.  "
 						"Change operating systems\n"
 						"or don't use this calc mode "
 						"in the future, sorry!\n");
-#else /* Windoz free systems */
+#else /* Windows free systems */
 					fprintf(stderr,
 						"Unable to associate stdin"
 						" with /dev/tty");
-#endif /* Windoz free systems */
+#endif /* Windows free systems */
 					set_run_state(RUN_EXIT_WITH_ERROR);
 					break;
 				}
