@@ -44,9 +44,11 @@
 #include "conf.h"
 #include "strl.h"
 
-#if defined(_WIN32) && !defined(__CYGWIN__)
+#if defined(_WIN32) || defined(_WIN64)
+#if !defined(__CYGWIN__)
 # include <direct.h>
 #endif
+#endif
 
 
 #include "banned.h"	/* include after system header <> includes */
@@ -451,7 +453,7 @@ getsimplebody(void)
 
 
 /*
- * Get the body of a function, or a subbody of a function.
+ * Get the body of a function, or a sub-body of a function.
  * body = '{' [ declarations ] ... [ statement ] ... '}'
  *	| [ declarations ] ... [statement ] ... '\n'
  */
@@ -1516,7 +1518,7 @@ getexprlist(void)
 
 
 /*
- * Get an opassignment or possibly just an assignment or expression.
+ * Get an op-assignment or possibly just an assignment or expression.
  * Returns flags describing the type of assignment or expression found.
  * assignment = lvalue '=' assignment
  *	| lvalue '+=' assignment
