@@ -1,7 +1,7 @@
 /*
  * const - constant number storage module
  *
- * Copyright (C) 1999-2007  David I. Bell
+ * Copyright (C) 1999-2007,2021  David I. Bell
  *
  * Calc is open software; you can redistribute it and/or modify it under
  * the terms of the version 2.1 of the GNU Lesser General Public License
@@ -28,6 +28,10 @@
 #include "calc.h"
 #include "qmath.h"
 
+
+#include "banned.h"	/* include after system header <> includes */
+
+
 #define CONSTALLOCSIZE 400	/* number of constants to allocate */
 
 STATIC unsigned long constcount;/* number of constants defined */
@@ -40,16 +44,16 @@ initconstants(void)
 {
 	int i;
 
-	consttable = (NUMBER **) malloc(sizeof(NUMBER *) * CONSTALLOCSIZE);
+	consttable = (NUMBER **) calloc(sizeof(NUMBER *), CONSTALLOCSIZE);
 	if (consttable == NULL) {
 		math_error("Unable to allocate constant table");
 		/*NOTREACHED*/
 	}
-	for (i = 0; i < INITCONSTCOUNT; i++)
+	for (i = 0; initnumbs[i] != NULL; i++) {
 		consttable[i] = initnumbs[i];
-	consttable[INITCONSTCOUNT] = NULL;	/* firewall */
-	constcount = INITCONSTCOUNT;
-	constavail = CONSTALLOCSIZE - INITCONSTCOUNT;
+	}
+	constcount = i-1;
+	constavail = CONSTALLOCSIZE - constcount;
 }
 
 
@@ -119,6 +123,9 @@ addqconstant(NUMBER *q)
 	tp = consttable;
 	for (index = 0; index < constcount; index++, tp++) {
 		t = *tp;
+		if (t == NULL) {	/* paranoia */
+			break;
+		}
 		if (t->links == 0) {
 			if (!havefirst) {
 				havefirst = TRUE;
