@@ -52,9 +52,9 @@
 
 
 /*
- * MS windoz macros
+ * MS Windows macros
  */
-#elif defined(_WIN32) || defined(WINDOZ)
+#elif defined(_WIN32) || defined(_WIN64)
 
 
   /* determine which type of DLL we must generate */
