@@ -26,7 +26,7 @@
 /*
  * Adapted from code written by Stephen Rothwell.
  *
- * GNU readline support added by Martin Buck <mbuck@debian.org>
+ * GNU readline support added by Martin Buck <mbuck at debian dot org>
  *
  * Interactive readline module.	 This is called to read lines of input,
  * while using emacs-like editing commands within a command stack.
@@ -36,7 +36,7 @@
 
 #include <stdio.h>
 #include <ctype.h>
-#if !defined(_WIN32)
+#if !defined(_WIN32) && !defined(_WIN64)
 # include <pwd.h>
 #endif
 
@@ -651,7 +651,7 @@ read_key(void)
 		cur_map = ent->next;
 	if (ent->func)
 		/* ignore Saber-C warning #65 - has 1 arg, expecting 0 */
-		/*	  ok to ignore in proc read_key */
+		/*	  OK to ignore in proc read_key */
 		(*ent->func)(key);
 	else
 		insert_char(key);
